import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="accountant",
    version="0.0.7",
    author="prakhar",
    author_email="author@example.com",
    description="Accountant package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    install_requires=["jsonrpcclient>=0.1.1",
                      "typing>=3.6",
                      "enum>=0.4",
                      "common>=0.1.1"],

    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
